marimo: Library for making reactive notebooks and apps
======================================================

Description
-----------

Library for making reactive notebooks and apps

License
-------

Apache License Version 2.0

Upstream Contact
----------------

https://pypi.org/project/marimo/
